@@ -22,7 +22,16 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 */
 
-#![deny(missing_docs, unsafe_code)]
+#![allow(missing_debug_implementations)]
+#![deny(
+    missing_copy_implementations,
+    trivial_casts,
+    trivial_numeric_casts,
+    unstable_features,
+    unused_import_braces,
+    unused_qualifications
+)]
+#![deny(clippy::all)]
 
 //! Scatterbrained implementation of minigrep.
 
@@ -69,12 +78,13 @@ impl Config {
 /* The lifetime parameters says that the search results will be valid as long as the contents are valid.
  * Can last even after pattern goes out of scope. */
 /// Returns the line(s) where the pattern is matched in the contents of the file.
-pub fn search<'a>(pattern: &str, content: &'a str) -> Vec<&'a str> {
-    let mut result: Vec<&str> = Vec::new();
+pub fn search<'a>(pattern: &'a str, content: &'a str) -> Vec<String> {
+    let mut result: Vec<String> = Vec::new();
 
-    for line in content.lines() {
-        if line.contains(pattern) {
-            result.push(line);
+    // TODO: Standardize lineno
+    for (lineno, linecon) in content.lines().enumerate() {
+        if linecon.contains(pattern) {
+            result.push(format!("{}: {}", lineno + 1, linecon));
         }
     }
 
@@ -108,7 +118,7 @@ pub fn run(config: Config) -> Result<(), Box<dyn Error>> {
 
     file.read_to_string(&mut data)?;
 
-    let result: Vec<&str> = search(&config.pattern, &data);
+    let result: Vec<String> = search(&config.pattern, &data);
 
     if result.is_empty() {
         println!("No match found for {} in {}", &config.pattern, &config.file);
@@ -152,9 +162,9 @@ mod test {
     #[test]
     fn case_sensitive() {
         let pattern: &str = "omg";
-        let data: &str = "omg, rust is so cool!";
+        let data: &str = "\n\n\n\nomg, rust is so cool!";
 
-        assert_eq!(vec![data], search(pattern, data));
+        assert_eq!(vec!["5: omg, rust is so cool!"], search(pattern, data));
     }
 
     #[test]
@@ -163,7 +173,7 @@ mod test {
         let data: &str = "Rust is the best.\nIt is the best.\nThe best!";
 
         assert_eq!(
-            vec!["Rust is the best.", "It is the best."],
+            vec!["1: Rust is the best.", "2: It is the best."],
             search(pattern, data)
         );
     }
@@ -173,6 +183,6 @@ mod test {
         let pattern: &str = "ok";
         let data: &str = "Ok, I'm going crazy!";
 
-        assert_ne!(vec![data], search(pattern, data));
+        assert_ne!(vec!["1: Ok, I'm going crazy!"], search(pattern, data));
     }
 }
